==> aware-0.0.7.tar.gz: ios/Classes/SwiftAwarePlugin.swift <==
import Flutter
import UIKit
import AIQAware

public class SwiftAwarePlugin: FlutterPluginAppLifeCycleDelegate, FlutterPlugin {
  private static let plistFileName = "AwareClient-Info"

  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "aware", binaryMessenger: registrar.messenger())
    let instance = SwiftAwarePlugin()
    registrar.addApplicationDelegate(instance)
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  private var authManager: AIQAwareAuthManager {
    get {
      return AIQAwareAuthManager.instance
    }
  }

  // todo(wonjerry): Delete these properties when AIQAwareAuthManagerDelegate callback updated
  private var registerResult: FlutterResult? = nil
  private var unregisterResult: FlutterResult? = nil

  override public func application(
      _ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [AnyHashable: Any]
  ) -> Bool {
    // Init AIQ.AWARE SDK
    AIQAware.configure(self)
    AIQAware.handleLaunchOptions(launchOptions as? [UIApplication.LaunchOptionsKey : Any])
    // Enable APNs
    application.registerForRemoteNotifications()
    // Enable background fetch
    application.setMinimumBackgroundFetchInterval(UIApplication.backgroundFetchIntervalMinimum)

    authManager.authManagerDelegate = self

    return super.application(application, didFinishLaunchingWithOptions: launchOptions)
  }

  public func application(
    _ application: UIApplication,
    performFetchWithCompletionHandler completionHandler: @escaping (UIBackgroundFetchResult) -> Void
  ) {
    // Handle background task
    AIQAware.performBackgroundFetchTask { completionHandler(.newData) }
  }

  override public func application(
    _ application: UIApplication,
    didRegisterForRemoteNotificationsWithDeviceToken deviceToken: Data
  ) {
    // Register APNs
    AIQAware.registerRemoteNotification(with: deviceToken, bundleId: Bundle.main.bundleIdentifier!)
  }

  public func applicationDidEnterBackground(_ application: UIApplication) {
    // Handle background ending process
    AIQAware.applicationDidEnterBackground(application)
  }

  private func convertCollectorNameToType(_ name: String) -> CollectorType? {
    switch(name) {
    case "airPressure":
      return CollectorType.airPressure
    case "battery":
      return CollectorType.battery
    case "calendar":
      return CollectorType.calendarEvent
    case "detectedActivity":
      return CollectorType.detectedActivity
    case "gravity":
      return CollectorType.gravity
    case "location":
      return CollectorType.location
    case "music":
      return CollectorType.music
    case "photo":
      return CollectorType.photo
    case "stepCount":
      return CollectorType.stepCount
    case "wifi":
      return CollectorType.wifi
    case "bluetooth", "sound", "sms":
      return nil
    default:
      return nil
    }
  }

  private func register(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
    let userHint = call.arguments as? String
    self.authManager.register(userHint: userHint)
    self.registerResult = result
  }

  private func unregister(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
    self.authManager.unregister()
    self.unregisterResult = result
  }

  private func getClientSecret(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
    var propertyListFormat =  PropertyListSerialization.PropertyListFormat.xml
    guard let plistPath: String = Bundle.main.path(forResource: plistFileName, ofType: "plist") else {
      result(FlutterError(code: call.method, message: "Add \(plistFileName) to the project", details: nil))
      return
    }
    let plistXML = FileManager.default.contents(atPath: plistPath)!
    do {
      let config = try PropertyListSerialization.propertyList(
        from: plistXML,
        options: .mutableContainersAndLeaves,
        format: &propertyListFormat
      ) as! [String: String]
      guard let apiKey = config["API_KEY"] else {
        result(FlutterError(code: call.method, message: "API key should be set", details: nil))
        return
      }
      result(apiKey)
    } catch {
      result(FlutterError(code: call.method, message: "Error reading plist: \(error), format: \(propertyListFormat)", details: nil))
    }
  }

  private func collect(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
    if !self.authManager.isRegistered {
      result(FlutterError(code: call.method, message: "Not registered yet", details: nil))
    }

    guard let collectorTypeNames = call.arguments as? [String] else {
      result(FlutterError(code: call.method, message: "Missing required arguements", details: nil))
      return
    }

    let collectorTypes = collectorTypeNames.map(convertCollectorNameToType)

    for collectorType in collectorTypes {
      if let type = collectorType {
        if !AIQAwareSignalManager.instance.isCollectingSignal(ofType: type) {
          AIQAwareSignalManager.instance.collect(type: type)
        }
      }
    }

    result(nil)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
      case "register":
        self.register(call, result)
      case "unregister":
        self.unregister(call, result)
      case "isRegistered":
        result(self.authManager.isRegistered)
      case "isServiceEnabled":
        result(true)
      case "setServiceEnabled":
        result(nil)
      case "getProfile":
        AIQAware.instance.getProfile(success: { (dictionary) in
          result(dictionary?.jsonStringRepresentation)
        }, failure: { (error: Error, _: Int?) in
          result(FlutterError(code: call.method, message: error.localizedDescription, details: nil))
        })
      case "getClientSecret":
        self.getClientSecret(call, result)
      case "collect":
        self.collect(call, result)
      default:
        result(FlutterMethodNotImplemented)
      }
  }
}

extension SwiftAwarePlugin: AIQAwareAuthManagerDelegate {
  public func registerSucceed(token: String) {
    if let result = self.registerResult {
      result(token)
      self.registerResult = nil
    }
  }

  public func registerFailed(reason: String) {
    if let result = self.registerResult {
      result(FlutterError(code: "register", message: reason, details: nil))
      self.registerResult = nil
    }
  }

  public func unregisterSucceed() {
    if let result = self.unregisterResult {
      result(true)
      self.unregisterResult = nil
    }
  }

  public func unregisterFailed(reason: String) {
    if let result = self.unregisterResult {
      result(FlutterError(code: "unregister", message: reason, details: nil))
      self.unregisterResult = nil
    }
  }
}

// todo(wonjerry): Delete when AIQAware updated
extension SwiftAwarePlugin: AIQAwareDelegate {
  public var permissionsToUse: Set<PermissionType>? {
    return nil
  }

  public var signalManagerDelegate: AIQAwareSignalManagerDelegate? {
    return nil
  }

  public var collectorsToUse: Set<CollectorType>? {
    return nil
  }
}

extension Dictionary {
  var jsonStringRepresentation: String? {
    guard let theJSONData = try? JSONSerialization.data(withJSONObject: self, options: [.prettyPrinted]) else {
        return nil
    }
    return String(data: theJSONData, encoding: .ascii)
  }
}

==> aware-0.1.1.tar.gz: ios/Classes/SwiftAwarePlugin.swift <==
import Flutter
import UIKit
import AIQAware

public class SwiftAwarePlugin: FlutterPluginAppLifeCycleDelegate, FlutterPlugin {
  private static let plistFileName = "AwareClient-Info"

  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "aware", binaryMessenger: registrar.messenger())
    let instance = SwiftAwarePlugin()
    registrar.addApplicationDelegate(instance)
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  private var authManager: AIQAwareAuthManager {
    get {
      return AIQAwareAuthManager.instance
    }
  }

  // todo(wonjerry): Delete these properties when AIQAwareAuthManagerDelegate callback updated
  private var registerResult: FlutterResult? = nil
  private var unregisterResult: FlutterResult? = nil

  override public func application(
      _ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [AnyHashable: Any]
  ) -> Bool {
    // Init AIQ.AWARE SDK
    AIQAware.configure(self)
    AIQAware.handleLaunchOptions(launchOptions as? [UIApplication.LaunchOptionsKey : Any])
    // Enable APNs
    application.registerForRemoteNotifications()
    // Enable background fetch
    application.setMinimumBackgroundFetchInterval(UIApplication.backgroundFetchIntervalMinimum)

    authManager.authManagerDelegate = self

    return super.application(application, didFinishLaunchingWithOptions: launchOptions)
  }

  public func application(
    _ application: UIApplication,
    performFetchWithCompletionHandler completionHandler: @escaping (UIBackgroundFetchResult) -> Void
  ) {
    // Handle background task
    AIQAware.performBackgroundFetchTask { completionHandler(.newData) }
  }

  override public func application(
    _ application: UIApplication,
    didRegisterForRemoteNotificationsWithDeviceToken deviceToken: Data
  ) {
    // Register APNs
    AIQAware.registerRemoteNotification(with: deviceToken, bundleId: Bundle.main.bundleIdentifier!)
  }

  public func applicationDidEnterBackground(_ application: UIApplication) {
    // Handle background ending process
    AIQAware.applicationDidEnterBackground(application)
  }

  private func convertCollectorNameToType(_ name: String) -> CollectorType? {
    switch(name) {
    case "airPressure":
      return CollectorType.airPressure
    case "battery":
      return CollectorType.battery
    case "calendar":
      return CollectorType.calendarEvent
    case "detectedActivity":
      return CollectorType.detectedActivity
    case "gravity":
      return CollectorType.gravity
    case "location":
      return CollectorType.location
    case "music":
      return CollectorType.music
    case "photo":
      return CollectorType.photo
    case "stepCount":
      return CollectorType.stepCount
    case "wifi":
      return CollectorType.wifi
    case "bluetooth", "sound", "sms":
      return nil
    default:
      return nil
    }
  }

  private func register(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
    // TODO (jwpark): Change signIn to register after SDK update
    if let ctoken = call.arguments as? String {
      self.authManager.signIn(clientToken: ctoken)
    } else {
      self.authManager.register()
    }
    self.registerResult = result
  }

  private func unregister(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
    self.authManager.unregister()
    self.unregisterResult = result
  }

  private func getClientSecret(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
    var propertyListFormat =  PropertyListSerialization.PropertyListFormat.xml
    guard let plistPath: String = Bundle.main.path(forResource: SwiftAwarePlugin.plistFileName, ofType: "plist") else {
      result(FlutterError(code: call.method, message: "Add \(SwiftAwarePlugin.plistFileName) to the project", details: nil))
      return
    }
    let plistXML = FileManager.default.contents(atPath: plistPath)!
    do {
      let config = try PropertyListSerialization.propertyList(
        from: plistXML,
        options: .mutableContainersAndLeaves,
        format: &propertyListFormat
      ) as! [String: String]
      guard let apiKey = config["API_KEY"] else {
        result(FlutterError(code: call.method, message: "API key should be set", details: nil))
        return
      }
      result(apiKey)
    } catch {
      result(FlutterError(code: call.method, message: "Error reading plist: \(error), format: \(propertyListFormat)", details: nil))
    }
  }

  private func collect(_ call: FlutterMethodCall, _ result: @escaping FlutterResult) {
    if !self.authManager.isRegistered {
      result(FlutterError(code: call.method, message: "Not registered yet", details: nil))
    }

    guard let collectorTypeNames = call.arguments as? [String] else {
      result(FlutterError(code: call.method, message: "Missing required arguements", details: nil))
      return
    }

    let collectorTypes = collectorTypeNames.map(convertCollectorNameToType)

    for collectorType in collectorTypes {
      if let type = collectorType {
        if !AIQAwareSignalManager.instance.isCollectingSignal(ofType: type) {
          AIQAwareSignalManager.instance.collect(type: type)
        }
      }
    }

    result(nil)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
    switch call.method {
      case "register":
        self.register(call, result)
      case "unregister":
        self.unregister(call, result)
      case "isRegistered":
        result(self.authManager.isRegistered)
      case "isServiceEnabled":
        result(true)
      case "setServiceEnabled":
        result(nil)
      case "getProfile":
        AIQAware.instance.getProfile(success: { (dictionary) in
          result(dictionary?.jsonStringRepresentation)
        }, failure: { (error: Error, _: Int?) in
          result(FlutterError(code: call.method, message: error.localizedDescription, details: nil))
        })
      case "getClientSecret":
        self.getClientSecret(call, result)
      case "collect":
        self.collect(call, result)
      default:
        result(FlutterMethodNotImplemented)
      }
  }
}

extension SwiftAwarePlugin: AIQAwareAuthManagerDelegate {
  public func registerSucceed(token: String) {
    if let result = self.registerResult {
      result(token)
      self.registerResult = nil
    }
  }

  public func registerFailed(reason: String) {
    if let result = self.registerResult {
      result(FlutterError(code: "register", message: reason, details: nil))
      self.registerResult = nil
    }
  }

  public func unregisterSucceed() {
    if let result = self.unregisterResult {
      result(true)
      self.unregisterResult = nil
    }
  }

  public func unregisterFailed(reason: String) {
    if let result = self.unregisterResult {
      result(FlutterError(code: "unregister", message: reason, details: nil))
      self.unregisterResult = nil
    }
  }
}

// todo(wonjerry): Delete when AIQAware updated
extension SwiftAwarePlugin: AIQAwareDelegate {
  public var permissionsToUse: Set<PermissionType>? {
    return nil
  }

  public var signalManagerDelegate: AIQAwareSignalManagerDelegate? {
    return nil
  }

  public var collectorsToUse: Set<CollectorType>? {
    return nil
  }
}

extension Dictionary {
  var jsonStringRepresentation: String? {
    guard let theJSONData = try? JSONSerialization.data(withJSONObject: self, options: [.prettyPrinted]) else {
        return nil
    }
    return String(data: theJSONData, encoding: .ascii)
  }
}
